@@ -20,6 +20,7 @@ import libvirt
 import math
 import monasca_agent.collector.checks.utils as utils
 import os
+import re
 import stat
 import subprocess
 import time
@@ -30,13 +31,8 @@ from datetime import datetime
 from datetime import timedelta
 from monasca_agent.collector.checks import AgentCheck
 from monasca_agent.collector.virt import inspector
-from monasca_agent.common import keystone
 from multiprocessing.dummy import Pool
 from netaddr import all_matching_cidrs
-from neutronclient.v2_0 import client as neutron_client
-from novaclient import client as n_client
-from novaclient.exceptions import NotFound
-
 
 DOM_STATES = {libvirt.VIR_DOMAIN_BLOCKED: 'VM is blocked',
               libvirt.VIR_DOMAIN_CRASHED: 'VM has crashed',
@@ -68,6 +64,7 @@ class LibvirtCheck(AgentCheck):
         self.use_bits = self.init_config.get('network_use_bits')
 
         self._collect_intervals = {}
+        self._host_aggregate = None
 
         self._set_collection_intervals('disk', 'disk_collection_period')
         self._set_collection_intervals('vnic', 'vnic_collection_period')
@@ -125,27 +122,35 @@ class LibvirtCheck(AgentCheck):
     def _update_instance_cache(self):
         """Collect instance_id, project_id, and AZ for all instance UUIDs
         """
+        from novaclient import client
+        from novaclient.exceptions import NotFound
 
         id_cache = {}
         flavor_cache = {}
         port_cache = None
         netns = None
         # Get a list of all instances from the Nova API
-        session = keystone.get_session(self.init_config)
-        nova_client = n_client.Client(
-            "2.1", session=session,
-            endpoint_type=self.init_config.get("endpoint_type", "publicURL"),
-            service_type="compute",
-            region_name=self.init_config.get('region_name'))
+        nova_client = client.Client(2,
+                                    username=self.init_config.get('admin_user'),
+                                    password=self.init_config.get('admin_password'),
+                                    project_name=self.init_config.get('admin_tenant_name'),
+                                    auth_url=self.init_config.get('identity_uri'),
+                                    endpoint_type='internalURL',
+                                    service_type="compute",
+                                    region_name=self.init_config.get('region_name'))
+        instances = nova_client.servers.list(search_opts={'all_tenants': 1,
+                                                          'host': self.hostname})
+        self._get_this_host_aggregate(nova_client)
 
-        instances = nova_client.servers.list(
-            search_opts={'all_tenants': 1, 'host': self.hostname})
         # Lay the groundwork for fetching VM IPs and network namespaces
         if self.init_config.get('ping_check'):
-            nu = neutron_client.Client(
-                session=session,
-                endpoint_type=self.init_config.get("endpoint_type", "publicURL"),
-                region_name=self.init_config.get('region_name'))
+            from neutronclient.v2_0 import client
+            nu = client.Client(username=self.init_config.get('admin_user'),
+                               password=self.init_config.get('admin_password'),
+                               tenant_name=self.init_config.get('admin_tenant_name'),
+                               auth_url=self.init_config.get('identity_uri'),
+                               endpoint_type='internalURL',
+                               region_name=self.init_config.get('region_name'))
             port_cache = nu.list_ports()['ports']
             # Finding existing network namespaces is an indication that either
             # DVR agent_mode is enabled, or this is all-in-one (like devstack)
@@ -593,7 +598,7 @@ class LibvirtCheck(AgentCheck):
 
     def prepare_run(self):
         """Check if it is time for measurements to be collected"""
-        for name, collection in self._collect_intervals.iteritems():
+        for name, collection in self._collect_intervals.items():
             if collection['period'] <= 0:
                 continue
 
@@ -702,6 +707,13 @@ class LibvirtCheck(AgentCheck):
                             dims_customer[metadata] = metadata_value
                 # Remove customer 'hostname' dimension, this will be replaced by the VM name
                 del(dims_customer['hostname'])
+                #
+                # Add this hypervisor's host aggregate as a dimension if
+                # configured to do so and we had a match on the regex for
+                # this host.
+                #
+                if self._host_aggregate:
+                    dims_operations['host_aggregate'] = self._host_aggregate
             except TypeError:
                 # Nova can potentially get into a state where it can't see an
                 # instance, but libvirt can.  This would cause TypeErrors as
@@ -766,7 +778,7 @@ class LibvirtCheck(AgentCheck):
                 self.gauge('vm.mem.resident_mb', float(memory_info.resident), dimensions=dims_operations)
             except KeyError:
                 self.log.debug("Balloon driver not active/available on guest {0} ({1})".format(inst_name,
-                                                                                               instance_cache.get(inst_name)['hostname']))
+                                                                                               instance_cache.get(inst_name)['hostname'].encode('utf8')))
             # Test instance's remote responsiveness (ping check) if possible
             if (self.init_config.get('vm_ping_check_enable')) and self.init_config.get('ping_check') and 'network' in instance_cache.get(inst_name):
                 for net in instance_cache.get(inst_name)['network']:
@@ -811,3 +823,24 @@ class LibvirtCheck(AgentCheck):
                 if metadata_value:
                     dims[metadata] = metadata_value
         return dims
+
+    def _get_this_host_aggregate(self, nova_client):
+        """Determine the host aggregate for this hypervisor."""
+        host_agg_cfg_re = self.init_config.get('host_aggregate_re', None)
+        if not host_agg_cfg_re:
+            return
+
+        try:
+            agg_re = re.compile(host_agg_cfg_re)
+            aggs = nova_client.aggregates.list()
+            for idx, agg in enumerate(aggs):
+                if re.match(agg_re, aggs[idx].name) and self.hostname in aggs[idx].hosts:
+                    self._host_aggregate = str(aggs[idx].name)
+                    #
+                    # Not expecting multiple matches, if we've got a match we're done.
+                    #
+                    break
+
+        except Exception as e:
+            msg = "Failed to list host aggregates, won't publish aggregate dimension: '{0}'"
+            self.log.error(msg.format(e))
