@@ -84,7 +84,7 @@ class OvsCheck(AgentCheck):
 
             if ifx not in ctr_cache:
                 ctr_cache[ifx] = {}
-            for metric_name, idx in self._get_metrics_map(measure).iteritems():
+            for metric_name, idx in self._get_metrics_map(measure).items():
                 interface_stats_key = self._get_interface_stats_key(idx, metric_name, measure, ifx)
                 statistics_dict = interface_data[ifx]['statistics']
                 value = statistics_dict[interface_stats_key] if interface_stats_key in statistics_dict else 0
@@ -135,7 +135,8 @@ class OvsCheck(AgentCheck):
         #
         tried_one_update = False
         host_router_max_bw = 0
-        for ifx, value in ifx_deltas.iteritems():
+        active_routers = 0
+        for ifx, value in ifx_deltas.items():
 
             port_uuid = value['port_uuid']
             if port_uuid not in port_cache and not tried_one_update:
@@ -172,6 +173,7 @@ class OvsCheck(AgentCheck):
                 ifx_dimensions = {'resource_id': device_uuid,
                                   'port_id': port_uuid,
                                   'router_name': router_name}
+                active_routers += 1
             else:
                 ifx_dimensions = {'resource_id': device_uuid,
                                   'port_id': port_uuid}
@@ -185,7 +187,7 @@ class OvsCheck(AgentCheck):
             if tenant_name:
                 ops_dimensions.update({'tenant_name': tenant_name})
 
-            for metric_name, idx in self._get_metrics_map(measure).iteritems():
+            for metric_name, idx in self._get_metrics_map(measure).items():
                 # POST to customer project
                 interface_stats_key = self._get_interface_stats_key(idx, metric_name, measure, ifx)
                 if interface_stats_key not in value:
@@ -233,6 +235,7 @@ class OvsCheck(AgentCheck):
             self.gauge('ovs.vrouter.host_max_bw_kb', host_router_max_bw,
                        dimensions=dims_base)
 
+        self.gauge('ovs.vrouter.active_routers', active_routers, dimensions=dims_base)
         self._update_counter_cache(ctr_cache,
                                    math.ceil(time.time() - time_start), measure)
 
