@@ -5,7 +5,9 @@
 import glob
 import logging
 import os
+import pstats
 import signal
+import six
 import sys
 import time
 
@@ -97,7 +99,7 @@ class CollectorDaemon(monasca_agent.common.daemon.Daemon):
             collection_start = time.time()
             # enable profiler if needed
             profiled = False
-            if config.get('profile', False) and config.get('profile').lower() == 'yes':
+            if config.get('profile', False):
                 try:
                     import cProfile
                     profiler = cProfile.Profile()
@@ -111,12 +113,10 @@ class CollectorDaemon(monasca_agent.common.daemon.Daemon):
             self.collector.run(check_frequency)
 
             # disable profiler and printout stats to stdout
-            if config.get('profile', False) and config.get('profile').lower() == 'yes' and profiled:
+            if config.get('profile', False) and profiled:
                 try:
                     profiler.disable()
-                    import cStringIO
-                    import pstats
-                    s = cStringIO.StringIO()
+                    s = six.StringIO()
                     ps = pstats.Stats(profiler, stream=s).sort_stats("cumulative")
                     ps.print_stats()
                     log.debug(s.getvalue())
@@ -272,7 +272,7 @@ def main():
             print("#" * 80)
             print("\n")
             print("You have to specify one of the following commands:")
-            for command, desc in jmxfetch.JMX_LIST_COMMANDS.iteritems():
+            for command, desc in jmxfetch.JMX_LIST_COMMANDS.items():
                 print("      - %s [OPTIONAL: LIST OF CHECKS]: %s" % (command, desc))
             print("Example: sudo /etc/init.d/monasca-agent jmx list_matching_attributes tomcat jmx solr")
             print("\n")
@@ -322,6 +322,6 @@ if __name__ == '__main__':
         # Try our best to log the error.
         try:
             log.exception("Uncaught error running the Agent")
-        except Exception:
+        except Exception:  # nosec
             pass
         raise
