@@ -75,7 +75,7 @@ class Kafka(Plugin):
                            'but neither %s nor %s '
                            'executable was found.'),
                           _KAFKA_CONSUMER_GROUP_COMMAND,
-                          _KAFKA_CONSUMER_GROUP_COMMAND)
+                          _KAFKA_ZOOKEEPER_SHELL_COMMAND)
 
     def _detect_consumers(self):
         """Using zookeeper and a kafka connection find the consumers and associated topics. """
@@ -238,7 +238,7 @@ class Kafka(Plugin):
             # If it did, delete it after use so it doesn't become a consumer group
             if 'service_name' in self.args:
                 service_name += '_' + str(self.args.pop('service_name'))
-            for key, value in self.args.iteritems():
+            for key, value in self.args.items():
                 value_dict = {topic: [] for topic in value.split('/')}
                 consumers[key] = value_dict
             self.config['kafka_consumer'] = {'init_config': None,
