@@ -92,7 +92,8 @@ class Ovs(detection.Plugin):
                            'dependence python-neutronclient is '
                            'not installed.'))
         else:
-            log.info("\tUsing neutron configuration file {0}".format(neutron_conf))
+            log.info("\tUsing neutron configuration file {0}".format(
+                    neutron_conf))
             self.neutron_conf = neutron_conf
 
     def _is_neutron_conf_valid(self, conf_file):
